/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.click.to.chat.web.internal.configuration;

import com.liferay.petra.reflect.ReflectionUtil;
import com.liferay.portal.kernel.module.configuration.ConfigurationException;
import com.liferay.portal.kernel.module.configuration.ConfigurationProviderUtil;
import com.liferay.portal.kernel.util.Validator;

import java.util.Objects;

/**
 * @author José Abelenda
 */
public class ClickToChatConfigurationUtil {

	public static ClickToChatConfiguration getClickToChatConfiguration(
		long companyId, long groupId) {

		try {
			ClickToChatConfiguration companyClickToChatConfiguration =
				ConfigurationProviderUtil.getCompanyConfiguration(
					ClickToChatConfiguration.class, companyId);

			if ((groupId == 0) ||
				Objects.equals(
					companyClickToChatConfiguration.siteSettingsStrategy(),
					"always-inherit")) {

				return companyClickToChatConfiguration;
			}

			ClickToChatConfiguration groupClickToChatConfiguration =
				ConfigurationProviderUtil.getGroupConfiguration(
					ClickToChatConfiguration.class, groupId);

			if (Objects.equals(
					companyClickToChatConfiguration.siteSettingsStrategy(),
					"always-override")) {

				return groupClickToChatConfiguration;
			}

			if (Objects.equals(
					companyClickToChatConfiguration.siteSettingsStrategy(),
					"inherit-or-override")) {

				if (Validator.isNotNull(
						groupClickToChatConfiguration.
							chatProviderAccountId()) &&
					Validator.isNotNull(
						groupClickToChatConfiguration.chatProviderId())) {

					return groupClickToChatConfiguration;
				}

				return companyClickToChatConfiguration;
			}

			return companyClickToChatConfiguration;
		}
		catch (ConfigurationException configurationException) {
			return ReflectionUtil.throwException(configurationException);
		}
	}

}